@@ -1,6 +1,4 @@
 import os
-import datetime
-import logging
 import json
 import uuid
 import hashlib
@@ -82,7 +80,7 @@ def singleton(class_):
 
 
 class Worker:
-    def __init__(self, worker_name, create_if_not_exist=True, segment_limit=200, connection_string=None):
+    def __init__(self, worker_name, create_if_not_exist=True, segment_limit=200, connection_string=None, return_only_source=True):
         if connection_string is None:
             self.connection_string = os.environ['AzureWebJobsStorage']
         else:
@@ -91,6 +89,7 @@ class Worker:
         self.queue_name = worker_name.lower()
         self.worker_name = worker_name
         self.segment_limit = segment_limit
+        self.return_only_source = return_only_source
 
         self.table_client = TableService(connection_string=self.connection_string)
         self.queue = QueueClient.from_connection_string(conn_str=self.connection_string, queue_name=self.queue_name)
@@ -257,8 +256,8 @@ class Worker:
         batch, result, failures = [], [], []
         in_blob = self._get_input_blob(blob_name)
         blobs_iterator = self._read_blob_by_segments(in_blob)
-        for source_segment in blobs_iterator:
-            batch.append(source_segment)
+        for segment in blobs_iterator:
+            batch.append(segment)
             if len(batch) == self.segment_limit:
                 result, failures = func(batch, params)
                 batch = []
@@ -268,8 +267,8 @@ class Worker:
             result, failures = func(batch, params)
 
         next_chunk = []
-        for source_segment in blobs_iterator:
-            next_chunk.append(source_segment)
+        for segment in blobs_iterator:
+            next_chunk.append(segment)
             if len(next_chunk) == self.segment_limit:
                 break
 
@@ -348,24 +347,29 @@ class Worker:
             lines = [l.strip() for l in chunk.decode().split("\r\n") if len(l.strip()) > 0]
             lines[0] = last_piece + lines[0]
             last_piece = lines[-1]
-            source_segments = []
+            segments = []
             for l in lines[:-1]:
                 l = self._preprocess(l)
                 if len(l) == 0:
                     continue
-                source_segment = self._preprocess(json.loads(l)[0])
-                source_segments.append(source_segment)
-            yield source_segments
+                source = self._preprocess(json.loads(l)[0])
+                target = self._preprocess(json.loads(l)[1])
+                if self.return_only_sources:
+                    segments.append(source)
+                else:
+                    segments.append((source, target))
+            yield segments
 
         last_piece = self._preprocess(last_piece)
         if len(last_piece) > 0:
             source = None
             try:
                 source = self._preprocess(json.loads(last_piece)[0])
+                target = self._preprocess(json.loads(last_piece)[1])
             except:
                 pass
             if source:
-                yield [source]
+                yield [source, target]
 
     @staticmethod
     def _preprocess(text):
@@ -382,13 +386,21 @@ class Worker:
                 l = self._preprocess(l)
                 if len(l) == 0:
                     continue
-                source_segment = self._preprocess(json.loads(l)[0])
-                yield source_segment
+                source = self._preprocess(json.loads(l)[0])
+                target = self._preprocess(json.loads(l)[1])
+                if self.return_only_source:
+                    yield source
+                else:
+                    yield source, target
 
         last_piece = self._preprocess(last_piece)
         if len(last_piece) > 0:
             source = self._preprocess(json.loads(last_piece)[0])
-            yield source
+            target = self._preprocess(json.loads(last_piece)[1])
+            if self.return_only_source:
+                yield source
+            else:
+                return source, target
 
     @staticmethod
     def _generate_request_id(data, guid=None):
